@@ -705,7 +705,7 @@ class TerminalWindow(ScrollText):
                 re=self.currentEditor()
                 re.delete("1.0","end")
                 re.insert("1.0","\n".join(t))
-                re.see(str(self.lastlno)+":0")
+                re.see(str(self.lastlno+1)+".0")
             else:
                 self.addTab(obj+':'+verb,"\n".join(t),1)
                 self.selectError(obj,verb,self.lastlno)
